<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://cloudimage.io
 * @since      1.0.0
 *
 * @package    Cloudimg
 * @subpackage Cloudimg/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Cloudimg
 * @subpackage Cloudimg/public
 * @author     Cloudimage <hello@cloudimage.io>
 */
class Cloudimg_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->cloudimg_options = get_option($this->plugin_name);

		if (isset($this->cloudimg_options['prod']) && $this->cloudimg_options['prod'] === 1)
		{
				define( 'CLOUDIMG_DEV_DEBUG', false );
		}

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cloudimg_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cloudimg_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/cloudimg-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Cloudimg_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Cloudimg_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		//wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/cloudimg-public.js', array( 'jquery' ), $this->version, false );

	}

	public function cloudimg_rewrite_url($src, $width=null, $height=null) {
  	return apply_filters("cloudimg_rewrite_url", false, $src, $width, $height);
	}

	public function photon_url_die($url, $src, $args, $scheme) {
	  error_log(print_r(array(
	    'url' => $url,
	    'src' => $src,
	    'args' => $args,
	    'scheme' => $scheme,
	  ), true));
	}

	/**
	 * Convert a jetpack request to a cloudimg request.
	 */
	public function jetpack_to_cloudimg_url($src, $args, $scheme) {
		  $width 	= 0;
			$height = 0;
			$fit 		= false;
			$func 	= '';

			if (!$this->cloudimg_options['token'])
			{
					return $src;
			}

		  if (array_key_exists('resize', $args))
			{
		    	list($width, $height) = explode(',', urldecode($args['resize']));
		  }
		  if (array_key_exists('fit', $args))
			{
		    	$fit = true;
		    	list($width, $height) = explode(',', urldecode($args['fit']));
		  }
		  if (array_key_exists('w', $args) && $args['w'])
			{
		    	$width = $args['w'];
		  }
		  if (array_key_exists('h', $args) && $args['h'])
			{
		    	$height = $args['h'];
		  }


	  if ($height > 0 && $width > 0)
	  {
	      if ($fit)
	      {
	          $func = 'fit';
	      }
	      else
	      {
	          $func = 'crop';
	      }
	      $size = $width . "x" . $height;
	  }
	  elseif ($height > 0)
	  {
	      $func = 'height';
	      $size = $height;
	  }
	  elseif ($width > 0)
	  {
	      $func = 'width';
	      $size = $width;
	  }
	  else
	  {
	      $func = 'cdn';
				$size = 'n';
	  }

		if (substr($src, 0, 7) == 'http://')
		{
				$src = substr($src, 7);
		}
		if (substr($src, 0, 8) == 'https://')
		{
				$src = substr($src, 8);
		}
		//echo "https://".$this->cloudimg_options['token'].".cloudimg.io/". $func . "/" . $size . '/n/' . $src;
	  return "https://".$this->cloudimg_options['token'].".cloudimg.io/". $func . "/" . $size . '/n/' . $src;
	}

	/**
	 * Convert a jetpack request to a cloudimg request.
	 */
	public function jetpack_to_cloudimg_background_url($src) {

			$func = 'cdn';
			$size = 'n';

			if (!$this->cloudimg_options['token'])
			{
					return $src;
			}

			if (substr($src, 0, 7) == 'http://')
			{
					$src = substr($src, 7);
			}
			if (substr($src, 0, 8) == 'https://')
			{
					$src = substr($src, 8);
			}
			return "https://".$this->cloudimg_options['token'].".cloudimg.io/". $func . "/" . $size . '/n/' . $src;
	}

}
